import arcpy
import pythonaddins
import webbrowser
import traceback
import sys

class ToolClass2(object):
    """Implementation for temp_addin.tool (Tool)"""
    def __init__(self):
        self.enabled = True
        self.shape = "NONE" # Can set to "Line", "Circle" or "Rectangle" for interactive shape drawing and to activate the onLine/Polygon/Circle event sinks.
  
    def onMouseDownMap(self, x, y, button, shift):
        try:
             # Get the current map document
            mxd = arcpy.mapping.MapDocument("CURRENT")

            # List all data frames, and get the first one 
            data_frame = arcpy.mapping.ListDataFrames(mxd)[0]

            # Get the dataframe spatial reference
            spatial_ref = data_frame.spatialReference
    
            # Initialize URL coordinates with the clicked map coordinates
            urlX = x
            urlY = y
            # Check if the current spatial reference does not match the target reference (code 3089), KY State Plane Single Zone
            # If not, reproject the coordinates to the target spatial reference
            if spatial_ref.factoryCode != 3089:
                
                # Create a point geometry object in the data frame spatial reference
                point = arcpy.Point(x, y)
                point_geometry = arcpy.PointGeometry(point, spatial_ref)
                # Reproject the point geometry to the target spatial reference
                point_geometry_sz = point_geometry.projectAs(arcpy.SpatialReference(3089))
                
                # Update URL coordinates with the reprojected point's coordinates
                urlX = point_geometry_sz.firstPoint.X
                urlY = point_geometry_sz.firstPoint.Y
                
            # Define the path to the Chrome browser executabler
            url= "https://explore.kyfromabove.ky.gov/?xy=" + str(urlX) + "," + str(urlY)
                      
            # Getting path of chrome executable
            chrome_path = r"C:\Program Files\Google\Chrome\Application\chrome.exe"
  
            # First registers chrome 
            webbrowser.register('chrome', None,  
            webbrowser.BackgroundBrowser(chrome_path)) 
  
            # Retrieve the registered Chrome browser and open the constructed URL
            browser = webbrowser.get('chrome')
            browser.open(url) 
           
           

        except:
            
              # get the traceback object
            tb = sys.exc_info()[2]
            # tbinfo contains the line number that the code failed on and the code from that line
            tbinfo = traceback.format_tb(tb)[0]
            # concatenate information together concerning the error into a message string
            pymsg = "PYTHON ERRORS:\nTraceback Info:\n" + tbinfo + "\nError Info:\n    " + \
            str(sys.exc_type)+ ": " + str(sys.exc_value) + "\n"
            # generate a message string for any geoprocessing tool errors
            msgs = "GP ERRORS:\n" + arcpy.GetMessages(2) + "\n"
            pythonaddins.MessageBox("Error:\n" + pymsg + "\n" + msgs, "Python Error", 0)